"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.updateComponentThemeMap = exports.generateBuildTimeMap = exports.updateComponentThemeMapForColorMode = exports.getResolvedProps = exports.getThemeProps = exports.setResolvedStyleMap = exports.getResolvedStyleMap = exports.init = exports.COLOR_SCHEME_MAP = exports.PSEUDO_PROP_COMPONENT_MAP = exports.resolvedStyledMap = void 0;

var _lodash = require("lodash");

var _getStyledComponentAndObjects = require("./getStyledComponentAndObjects");

var _theme = require("../theme");

var _propsFlattener = require("../hooks/useThemeProps/propsFlattener");

var _isEmptyObj = require("../utils/isEmptyObj");

// Adding Map for storing the props and style for the styled component
let resolvedStyledMap = {};
exports.resolvedStyledMap = resolvedStyledMap;
const PSEUDO_PROP_COMPONENT_MAP = {
  _spinner: 'Spinner',
  _stack: 'Stack',
  _text: 'Text',
  _icon: 'Icon',
  _checkbox: 'Checkbox',
  _radio: 'Radio',
  _pressable: 'Pressable',
  _slide: 'Slide',
  _fade: 'Fade',
  _backdropFade: 'BackdropFace'
};
exports.PSEUDO_PROP_COMPONENT_MAP = PSEUDO_PROP_COMPONENT_MAP;
const COLOR_SCHEME_MAP = {
  Button: true,
  ButtonGroup: true,
  IconButton: true,
  Checkbox: true,
  Radio: true,
  Alert: true,
  Badge: true,
  CircularProgress: true,
  Fab: true,
  Modal: true,
  Progress: true,
  Switch: true,
  Tag: true,
  Slider: true,
  SliderThumb: true,
  // SliderTrack: true,
  SliderFilledTrack: true
};
exports.COLOR_SCHEME_MAP = COLOR_SCHEME_MAP;

const init = inputResolvedStyledMap => {
  if (inputResolvedStyledMap) {
    exports.resolvedStyledMap = resolvedStyledMap = inputResolvedStyledMap;
  }

  if (process.env.NODE_ENV === 'development') {
    //@ts-ignore
    window['resolvedStyledMap'] = resolvedStyledMap; //@ts-ignore
  }
};

exports.init = init;

const getResolvedStyleMap = (providerId, key) => {
  return resolvedStyledMap[providerId][key];
};

exports.getResolvedStyleMap = getResolvedStyleMap;

const setResolvedStyleMap = (providerId, key, value, colorMode) => {
  if (!resolvedStyledMap[providerId]) {
    resolvedStyledMap[providerId] = {};
  }

  const styledMap = resolvedStyledMap[providerId][key];

  if (!styledMap) {
    resolvedStyledMap[providerId][key] = {
      [colorMode]: [value]
    };
  } else {
    if (!styledMap[colorMode]) {
      styledMap[colorMode] = [];
    }

    styledMap[colorMode].push(value);
  }
};

exports.setResolvedStyleMap = setResolvedStyleMap;

const getThemeObject = (providerId, componentName, colorMode, state) => {
  var _resolvedStyledMap, _resolvedStyledMap$pr;

  const styleObj = (_resolvedStyledMap = resolvedStyledMap) === null || _resolvedStyledMap === void 0 ? void 0 : (_resolvedStyledMap$pr = _resolvedStyledMap[providerId]) === null || _resolvedStyledMap$pr === void 0 ? void 0 : _resolvedStyledMap$pr[componentName];

  if (!styleObj || !styleObj[colorMode]) {
    return {};
  } // Theme style


  let styleSheet = styleObj[colorMode]; // state style

  const stateStyles = getPseudoStateStyles(providerId, componentName, state);

  if (componentName === 'Checkbox' && state.isInvalid && state.isHovered) {// console.log(componentName, stateStyles, 'component state');
  }

  (0, _lodash.forEach)(stateStyles, stateStyleObj => {
    if (stateStyleObj[colorMode]) {
      styleSheet = styleSheet.concat(stateStyleObj[colorMode]);
    }
  });
  const unResolvedPropsArray = (0, _lodash.map)(styleSheet, 'unResolvedProps');
  let unResolvedProps = {};

  for (const props of unResolvedPropsArray) {
    // unResolvedProps = { ...unResolvedProps, ...props };
    unResolvedProps = (0, _lodash.merge)({}, unResolvedProps, props);
  }

  const restDefaultPropsArray = (0, _lodash.map)(styleSheet, 'restDefaultProps');
  let restDefaultProps = {};

  for (const props of restDefaultPropsArray) {
    restDefaultProps = { ...restDefaultProps,
      ...props
    };
  }

  const styleFromPropsArray = (0, _lodash.map)(styleSheet, 'styleFromProps');
  let styleFromProps = {};

  for (const props of styleFromPropsArray) {
    styleFromProps = { ...styleFromProps,
      ...props
    };
  }

  const internalPseudoPropsArray = (0, _lodash.map)(styleSheet, 'internalPseudoProps');
  let internalPseudoProps = {};

  for (const props of internalPseudoPropsArray) {
    internalPseudoProps = { ...internalPseudoProps,
      ...props
    };
  }

  return {
    style: (0, _lodash.map)(styleSheet, 'style'),
    unResolvedProps: unResolvedProps,
    styleFromProps: styleFromProps,
    restDefaultProps: restDefaultProps,
    internalPseudoProps: internalPseudoProps
  };
};

const getComponentNameKeyFromProps = (componentName, {
  variant,
  colorScheme
} = {}) => {
  let componentKeyName = componentName; // const componentTheme = lodashGet(theme, `components.${componentName}`, {});

  const colorSchemeKey = colorScheme; // || componentTheme.defaultProps?.colorScheme;

  const variantKey = variant; // || componentTheme.defaultProps?.variant;

  if (colorSchemeKey && variantKey) {
    componentKeyName = "".concat(componentName, ".").concat(colorSchemeKey, ".").concat(variantKey);
  } else if (variantKey) {
    componentKeyName = "".concat(componentName, ".").concat(variant);
  } else if (colorSchemeKey) {
    componentKeyName = "".concat(componentName, ".").concat(colorSchemeKey);
  }

  return componentKeyName;
}; // const get


const getThemeProps = (theme, providerId, inputComponentKeyName, config, state, props = {}) => {
  const componentNames = inputComponentKeyName.split('.');
  const rootComponentName = componentNames[0];
  const pseudoComponentKeyName = componentNames[1];
  let componentKeyName = rootComponentName;
  componentKeyName = getComponentNameKeyFromProps(rootComponentName, props);

  if (pseudoComponentKeyName) {
    componentKeyName = "".concat(componentKeyName, ".").concat(pseudoComponentKeyName);
  }

  let themeObj = getThemeObject(providerId, componentKeyName, config.colorMode, state); // console.log(themeObj, providerId, 'theme obje');

  if ((0, _isEmptyObj.isEmptyObj)(themeObj)) {
    // console.log('hello here 1111', inputComponentKeyName);
    // updateComponentThemeMap(inputComponentKeyName, {}, config, {});
    updateComponentThemeMap(theme, providerId, inputComponentKeyName, {}, config, {
      variant: props.variant,
      colorScheme: props.colorScheme
    });
    themeObj = getThemeObject(providerId, componentKeyName, config.colorMode, state);
  }

  if (!(0, _isEmptyObj.isEmptyObj)(themeObj) && props.size) {
    var _sizeThemeObj, _themeObj, _sizeThemeObj2;

    let componentKeyNameForSize = "".concat(rootComponentName, ".").concat(props.size);

    if (pseudoComponentKeyName) {
      componentKeyNameForSize = "".concat(componentKeyNameForSize, ".").concat(pseudoComponentKeyName);
    }

    let sizeThemeObj = getThemeObject(providerId, "".concat(componentKeyNameForSize), config.colorMode, state);

    if ((0, _isEmptyObj.isEmptyObj)(sizeThemeObj)) {
      if (!pseudoComponentKeyName) {
        if ((0, _isEmptyObj.isEmptyObj)(sizeThemeObj)) {
          updateComponentThemeMap(theme, providerId, rootComponentName, {}, config, {
            size: props.size
          });
          sizeThemeObj = getThemeObject(providerId, componentKeyNameForSize, config.colorMode, state);
        }
      }
    }

    const mergedThemeObj = {
      style: (_sizeThemeObj = sizeThemeObj) !== null && _sizeThemeObj !== void 0 && _sizeThemeObj.style ? [...((_themeObj = themeObj) === null || _themeObj === void 0 ? void 0 : _themeObj.style), ...((_sizeThemeObj2 = sizeThemeObj) === null || _sizeThemeObj2 === void 0 ? void 0 : _sizeThemeObj2.style)] : themeObj.style,
      styleFromProps: (0, _lodash.merge)({}, themeObj.styleFromProps, sizeThemeObj.styleFromProps),
      unResolvedProps: (0, _lodash.merge)({}, themeObj.unResolvedProps, sizeThemeObj.unResolvedProps),
      internalPseudoProps: (0, _lodash.merge)({}, themeObj.internalPseudoProps, sizeThemeObj.internalPseudoProps),
      restDefaultProps: { ...themeObj.restDefaultProps,
        ...sizeThemeObj.restDefaultProps
      }
    };
    themeObj = mergedThemeObj;
  }

  return themeObj;
};

exports.getThemeProps = getThemeProps;

const getResolvedProps = (key, colorMode) => {
  const styleObj = resolvedStyledMap[key];

  if (!colorMode || !styleObj) {
    return null;
  }

  return styleObj[colorMode]['styleFromProps'];
};

exports.getResolvedProps = getResolvedProps;

const isValidStateKey = (stateKey, state) => {
  // console.log(stateKey, pseudoPropStateMap[stateKey], state, 'is valid');
  try {
    //@ts-ignore
    return state[_propsFlattener.pseudoPropsMap[stateKey].respondTo];
  } catch (e) {
    return false;
  }
};

const isValidState = (key, state) => {
  // include only startWith("_")
  const stateKeys = key.split('.');
  const isValid = stateKeys.every(stateKey => {
    if (isValidStateKey(stateKey, state)) {
      return true;
    }

    return false;
  }); // console.log(isValid, 'valid here');

  return isValid;
};

const getPriority = propName => {
  const propNameArray = propName.split('.');
  const maxPriority = propNameArray.reduce((previousValue, currentValue) => {
    var _pseudoPropsMap$curre;

    //@ts-ignore
    return Math.max(previousValue, (_pseudoPropsMap$curre = _propsFlattener.pseudoPropsMap[currentValue]) === null || _pseudoPropsMap$curre === void 0 ? void 0 : _pseudoPropsMap$curre.priority);
  }, 0);
  const priority = //@ts-ignore
  maxPriority + propNameArray.length / 10; // }

  return priority;
};

const getPseudoStateStyles = (providerId, componentName, state) => {
  const styleObj = [];
  const stateStyleArray = [];
  const componentStates = getResolvedStyleMap(providerId, componentName); // console.log(componentStates, '***** &&&&');
  // const currentPriority = 0;

  for (const k in componentStates) {
    const value = componentStates[k]; // console.log(componentStates, k, componentName, 'value **&');
    //get for _hover, _checked

    if (k.startsWith('_')) {
      const priority = getPriority(k);
      stateStyleArray.push({
        key: k,
        value: value,
        priority: priority
      });
    }
  }

  stateStyleArray.sort((obj1, obj2) => obj1.priority - obj2.priority);
  stateStyleArray.forEach(item => {
    if (isValidState(item.key, state)) {
      styleObj.push(item.value);
    }
  });
  return styleObj;
};

const resolveForInternalPseudoProps = (theme, providerId, name, key, styledObj, config, mergeDefaultProps = true, propertyName) => {
  // if (name !== 'Button') {
  //   return;
  // }
  for (const property in styledObj.internalPseudoProps) {
    if (PSEUDO_PROP_COMPONENT_MAP[property]) {
      //TODO: not calling again for nested state prop
      if (!propertyName) {
        updateComponentThemeMapForColorMode(theme, providerId, PSEUDO_PROP_COMPONENT_MAP[property], "".concat(key, ".").concat(PSEUDO_PROP_COMPONENT_MAP[property]), styledObj.internalPseudoProps[property], config, false, mergeDefaultProps);
      }
    } else {
      // const themeProps = getThemeProps(name, colorMode, {
      //   [pseudoPropStateMap[property]]: true,
      // });
      // if (property === '_hover') {
      //   console.log(
      //     // name,
      //     // property,
      //     // pseudoPropStateMap[property],
      //     themeProps,
      //     {
      //       ...themeProps.styleFromProps,
      //       ...styledObj.internalPseudoProps[property],
      //     },
      //     'theme props '
      //   );
      // }
      // console.log(name, key, 'config here');
      const styledObjNestedProp = (0, _getStyledComponentAndObjects.getStyledObject)(theme, name, {}, config, styledObj.internalPseudoProps[property]);
      const componentMapPath = key;
      const componentObj = getResolvedStyleMap(providerId, componentMapPath);

      if (componentObj) {
        var _pseudoPropsMap$prope;

        // const stateKey = key.slice(componentMapPath.length + 1);
        //@ts-ignore
        if (_propsFlattener.pseudoPropsMap !== null && _propsFlattener.pseudoPropsMap !== void 0 && (_pseudoPropsMap$prope = _propsFlattener.pseudoPropsMap[property]) !== null && _pseudoPropsMap$prope !== void 0 && _pseudoPropsMap$prope.respondTo) {
          const stateKey = propertyName ? propertyName + '.' + property : property;

          if (componentObj[stateKey]) {
            if (!componentObj[stateKey][config.colorMode]) {
              componentObj[stateKey][config.colorMode] = [];
            }

            componentObj[stateKey][config.colorMode].push(styledObjNestedProp);
          } else {
            componentObj[stateKey] = {
              [config.colorMode]: [styledObjNestedProp]
            };
          } // if (name == 'Checkbox') {
          //   console.log(
          //     // property,
          //     key,
          //     // componentObj,
          //     // componentMapPath,
          //     styledObjNestedProp,
          //     'hello here 111'
          //   );
          // if (!isEmptyObj(styledObjNestedProp.internalPseudoProps)) {


          resolveForInternalPseudoProps(theme, providerId, name, key, styledObjNestedProp, config, false, property); // }
          // }
        } else {
          // console.log(
          //   'hello here &&&*',
          //   styledObj.internalPseudoProps[property]
          // );
          if (!propertyName) {
            componentObj[config.colorMode][0].unResolvedProps = { ...componentObj[config.colorMode][0].unResolvedProps,
              [property]: styledObj.internalPseudoProps[property]
            };
          } else {
            componentObj[propertyName][config.colorMode][0].unResolvedProps = { ...componentObj[propertyName][config.colorMode][0].unResolvedProps,
              [property]: styledObj.internalPseudoProps[property]
            };
          }
        }
      }
    }
  }
};

const updateComponentThemeMapForColorMode = (theme, providerId, name, key, inputProps, config = {
  colorMode: 'light',
  platform: 'web'
}, resolveForStatePseudoProps = false, mergeDefaultProps = true) => {
  // console.log(theme, 'theme here');
  let componentTheme = (0, _lodash.get)(theme, "components.".concat(name), {}); // let componentTheme = get(defaultTheme, `components.${name}`, {});
  // if (runtime) {
  //   componentTheme =
  // }
  // resolve for variant

  if (resolveForStatePseudoProps) {
    componentTheme = {};
  }

  const styledObj = (0, _getStyledComponentAndObjects.getStyledObject)(theme, name, componentTheme, config, { ...inputProps,
    extraProp: key
  }, mergeDefaultProps);
  setResolvedStyleMap(providerId, key, styledObj, config.colorMode); // console.log(key, styledObj, config.colorMode, '&&&&&&');

  resolveForInternalPseudoProps(theme, providerId, name, key, styledObj, config, mergeDefaultProps);
  return styledObj;
}; // export const resolveDefaultTheme = (platform?: string) => {
//   // for (const key in theme.components) {
//   //   // console.log(key, platform);
//   //   updateComponentThemeMap(key, {}, { platform });
//   // }
//   // return resolvedStyledMap;
// };


exports.updateComponentThemeMapForColorMode = updateComponentThemeMapForColorMode;

const generateBuildTimeMap = (platform = 'web', usedComponentDetailMap) => {
  const componentsUsed = Object.keys(usedComponentDetailMap);

  for (const componentName of componentsUsed) {
    const componentPropsArray = usedComponentDetailMap[componentName];

    for (const componentProps of componentPropsArray) {
      updateComponentThemeMap(_theme.theme, // boot time provider id
      1, componentName, {}, {
        platform,
        colorMode: 'light'
      }, componentProps);
      updateComponentThemeMap(_theme.theme, // boot time provider id
      1, componentName, {}, {
        platform,
        colorMode: 'dark'
      }, componentProps);
    }
  } // return resolvedStyledMap;

};

exports.generateBuildTimeMap = generateBuildTimeMap;

const updateComponentThemeMap = (theme, providerId, name, inputProps, config = {
  platform: 'web',
  colorMode: 'light'
}, props) => {
  const {
    platform,
    colorMode
  } = config; // console.log(props, 'props here');
  // const componentTheme = get(theme, `components.${name}`, {});

  let themeObj = {}; // if (runTimeResolution) {

  const currentColorScheme = props === null || props === void 0 ? void 0 : props.colorScheme; // || componentTheme?.defaultProps?.colorScheme;

  const currentVariant = props === null || props === void 0 ? void 0 : props.variant; // || componentTheme?.defaultProps?.variant;

  const currentSize = props === null || props === void 0 ? void 0 : props.size; // || componentTheme?.defaultProps?.size;

  if (currentVariant && currentColorScheme) {
    themeObj = updateComponentThemeMapForColorMode(theme, providerId, name, "".concat(name, ".").concat(currentColorScheme, ".").concat(currentVariant), {
      variant: currentVariant,
      colorScheme: currentColorScheme
    }, {
      colorMode,
      platform
    });
  } else if (currentColorScheme) {
    // if (name === 'SliderThumb') {
    //   console.log(props, 'hello slider ');
    // }
    themeObj = updateComponentThemeMapForColorMode(theme, providerId, name, "".concat(name, ".").concat(currentColorScheme), {
      colorScheme: currentColorScheme
    }, {
      colorMode,
      platform
    });
  } else if (currentVariant) {
    themeObj = updateComponentThemeMapForColorMode(theme, providerId, name, "".concat(name, ".").concat(currentVariant), {
      variant: currentVariant
    }, {
      colorMode,
      platform
    });
  } else if (currentSize) {
    // console.log(name, 'name here 111', currentSize);
    // if (name == 'Button') {
    //   console.trace('hh');
    // }
    themeObj = updateComponentThemeMapForColorMode(theme, providerId, name, "".concat(name, ".").concat(currentSize), {
      size: currentSize
    }, {
      colorMode,
      platform
    }, false, false);
  } else {
    themeObj = updateComponentThemeMapForColorMode(theme, providerId, name, name, inputProps, {
      colorMode,
      platform
    }, false, true);
  }

  return themeObj;
};

exports.updateComponentThemeMap = updateComponentThemeMap;
//# sourceMappingURL=styled.js.map