import React, { memo, forwardRef } from 'react';
import Box from '../../primitives/Box';
// import { HStack } from '../../primitives/Stack';
import { usePropsResolution } from '../../../hooks/useThemeProps';
import type { IAlertProps } from './types';
import { AlertContext } from './Context';

const Alert = ({ children, ...props }: IAlertProps, ref?: any) => {
  const {
    status,
    variant,
    _icon,
    colorScheme,
    ...newProps
  } = usePropsResolution('Alert', {
    ...props,
    colorScheme: props.status ? props.status : props.colorScheme,
  });

  // console.log(newProps, colorScheme, 'props here');
  return (
    <AlertContext.Provider
      value={{
        status,
        variant,
        _icon,
        colorScheme,
      }}
    >
      <Box {...newProps} ref={ref}>
        {children}
      </Box>
    </AlertContext.Provider>
  );
};

export default memo(forwardRef(Alert));
